Trademark Attributions
##########################


 - MacOS® is a trademark of Apple Inc., registered in the U.S. and other countries.
 - Linux® is the registered trademark of Linus Torvalds in the U.S. and other countries.
